@@ -1,11 +1,12 @@
 extern crate devserver_lib;
 use std::env;
+use std::path::Path;
 
 fn main() {
     let args: Vec<String> = env::args().collect();
 
     let mut address: String = "localhost:8000".to_string();
-
+    let mut path: String = "".to_string();
     let mut args = args.iter();
     while let Some(arg) = args.next() {
         match arg.as_ref() {
@@ -15,16 +16,23 @@ fn main() {
                     .expect("Pass an address with a port after the '--address' flag")
                     .to_string()
             }
+            "--path" => {
+                path = args
+                    .next()
+                    .expect("Pass a path after the '--path' flag")
+                    .to_string()
+            }
             "--help" => {
                 println!(
                     r#"Run 'devserver' in a folder to host that folder.
 
 --address [address]:[port] Specify an address to use. The default is 'localhost:8000'.
+--path [path]              Specify the path of the folder to be hosted.
 --help                     Display the helpful information you're reading right now.
 
 Examples:
 
-devserver --address 127.0.0.1:8080
+devserver --address 127.0.0.1:8080 --path "some_directory/subdirectory"
 
                 "#
                 );
@@ -33,14 +41,13 @@ devserver --address 127.0.0.1:8080
             _ => {}
         }
     }
-
-    let path = env::current_dir().unwrap();
+    let hosted_path = env::current_dir().unwrap().join(Path::new(&path));
 
     println!(
         "Serving [{}] at [https://{}] or [http://{}] ",
-        path.display(),
+        hosted_path.display(),
         address,
         address
     );
-    devserver_lib::run(&address); // Runs forever serving the current folder on https://localhost:8000
+    devserver_lib::run(&address, &path);
 }
